==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/entity/SwDjGdzys.java <==
package cn.gtmap.landtax.entity;

import com.alibaba.fastjson.annotation.JSONField;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import javax.persistence.*;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 批次信息
 */
@Entity
@org.hibernate.annotations.Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@Table(name = "SW_DJ_GDZYS")
public class SwDjGdzys {
    @Id
    @Column
    private String gdzysId;

    @Column(name = "szly")
    private String gdzysSzly;

    @Column(name="ynse")
    private BigDecimal gdzysYnse;

    @Column(name="dwse")
    private BigDecimal gdzysDwse;

    @Column(name="jmxz")
    private String gdzysJmxz;

    @Column(name="jmse")
    private BigDecimal gdzysJmse;

    @Column(name="jspz")
    private String gdzysJspz;

    @Column(name="yjne")
    private BigDecimal gdzysYjne;

    @Column(name="xbjse")
    private BigDecimal gdzysXbjse;

    @Column(name="bz")
    private String gdzysBz;

    @Column(name="lrrq")
    private Date gdzysLrrq;

    @Column(name="hclx")
    private String gdzysHclx;

    @Column(name="gdzys_ZT")
    private String gdzysZt;

    @JSONField(serialize = false)
    @OneToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "SY_ID")
    private SwDjSy swDjSy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "JBB_ID")
    private SwDjJbb swDjJbb;

    public String getGdzysId() {
        return gdzysId;
    }

    public void setGdzysId(String gdzysId) {
        this.gdzysId = gdzysId;
    }

    public String getGdzysSzly() {
        return gdzysSzly;
    }

    public void setGdzysSzly(String gdzysSzly) {
        this.gdzysSzly = gdzysSzly;
    }

    public BigDecimal getGdzysYnse() {
        return gdzysYnse;
    }

    public void setGdzysYnse(BigDecimal gdzysYnse) {
        this.gdzysYnse = gdzysYnse;
    }

    public BigDecimal getGdzysDwse() {
        return gdzysDwse;
    }

    public void setGdzysDwse(BigDecimal gdzysDwse) {
        this.gdzysDwse = gdzysDwse;
    }

    public String getGdzysJmxz() {
        return gdzysJmxz;
    }

    public void setGdzysJmxz(String gdzysJmxz) {
        this.gdzysJmxz = gdzysJmxz;
    }

    public BigDecimal getGdzysJmse() {
        return gdzysJmse;
    }

    public void setGdzysJmse(BigDecimal gdzysJmse) {
        this.gdzysJmse = gdzysJmse;
    }

    public String getGdzysJspz() {
        return gdzysJspz;
    }

    public void setGdzysJspz(String gdzysJspz) {
        this.gdzysJspz = gdzysJspz;
    }

    public BigDecimal getGdzysYjne() {
        return gdzysYjne;
    }

    public void setGdzysYjne(BigDecimal gdzysYjne) {
        this.gdzysYjne = gdzysYjne;
    }

    public BigDecimal getGdzysXbjse() {
        return gdzysXbjse;
    }

    public void setGdzysXbjse(BigDecimal gdzysXbjse) {
        this.gdzysXbjse = gdzysXbjse;
    }

    public String getGdzysBz() {
        return gdzysBz;
    }

    public void setGdzysBz(String gdzysBz) {
        this.gdzysBz = gdzysBz;
    }

    public Date getGdzysLrrq() {
        return gdzysLrrq;
    }

    public void setGdzysLrrq(Date gdzysLrrq) {
        this.gdzysLrrq = gdzysLrrq;
    }

    public SwDjSy getSwDjSy() {
        return swDjSy;
    }

    public SwDjJbb getSwDjJbb() {
        return swDjJbb;
    }

    public void setSwDjJbb(SwDjJbb swDjJbb) {
        this.swDjJbb = swDjJbb;
    }

    public void setSwDjSy(SwDjSy swDjSy) {
        this.swDjSy = swDjSy;
    }

    public String getGdzysHclx() {
        return gdzysHclx;
    }

    public void setGdzysHclx(String gdzysHclx) {
        this.gdzysHclx = gdzysHclx;
    }

    public String getGdzysZt() {
        return gdzysZt;
    }

    public void setGdzysZt(String gdzysZt) {
        this.gdzysZt = gdzysZt;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/entity/SwDjGdzys.java <==
package cn.gtmap.landtax.entity;

import com.alibaba.fastjson.annotation.JSONField;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import javax.persistence.*;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 批次信息
 */
@Entity
@org.hibernate.annotations.Cache(usage = CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
@Table(name = "SW_DJ_GDZYS")
public class SwDjGdzys {
    @Id
    @Column
    private String gdzysId;

    @Column(name = "szly")
    private String gdzysSzly;

    @Column(name="ynse")
    private BigDecimal gdzysYnse;

    @Column(name="dwse")
    private BigDecimal gdzysDwse;

    @Column(name="jmxz")
    private String gdzysJmxz;

    @Column(name="jmse")
    private BigDecimal gdzysJmse;

    @Column(name="jspz")
    private String gdzysJspz;

    @Column(name="yjne")
    private BigDecimal gdzysYjne;

    @Column(name="xbjse")
    private BigDecimal gdzysXbjse;

    @Column(name="bz")
    private String gdzysBz;

    @Column(name="lrrq")
    private Date gdzysLrrq;

    @Column(name="hclx")
    private String gdzysHclx;

    @Column(name="gdzys_ZT")
    private String gdzysZt;

    public String getPcId() {
        return pcId;
    }

    public void setPcId(String pcId) {
        this.pcId = pcId;
    }

    @Column(name="PC_ID")
    private String pcId;

    @Column(name="ZDSYBZ")
    private String zdsybz;

    public String getZdsybz() {
        return zdsybz;
    }

    public void setZdsybz(String zdsybz) {
        this.zdsybz = zdsybz;
    }


    @JSONField(serialize = false)
    @OneToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "SY_ID")
    private SwDjSy swDjSy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "JBB_ID")
    private SwDjJbb swDjJbb;

    public String getGdzysId() {
        return gdzysId;
    }

    public void setGdzysId(String gdzysId) {
        this.gdzysId = gdzysId;
    }

    public String getGdzysSzly() {
        return gdzysSzly;
    }

    public void setGdzysSzly(String gdzysSzly) {
        this.gdzysSzly = gdzysSzly;
    }

    public BigDecimal getGdzysYnse() {
        return gdzysYnse;
    }

    public void setGdzysYnse(BigDecimal gdzysYnse) {
        this.gdzysYnse = gdzysYnse;
    }

    public BigDecimal getGdzysDwse() {
        return gdzysDwse;
    }

    public void setGdzysDwse(BigDecimal gdzysDwse) {
        this.gdzysDwse = gdzysDwse;
    }

    public String getGdzysJmxz() {
        return gdzysJmxz;
    }

    public void setGdzysJmxz(String gdzysJmxz) {
        this.gdzysJmxz = gdzysJmxz;
    }

    public BigDecimal getGdzysJmse() {
        return gdzysJmse;
    }

    public void setGdzysJmse(BigDecimal gdzysJmse) {
        this.gdzysJmse = gdzysJmse;
    }

    public String getGdzysJspz() {
        return gdzysJspz;
    }

    public void setGdzysJspz(String gdzysJspz) {
        this.gdzysJspz = gdzysJspz;
    }

    public BigDecimal getGdzysYjne() {
        return gdzysYjne;
    }

    public void setGdzysYjne(BigDecimal gdzysYjne) {
        this.gdzysYjne = gdzysYjne;
    }

    public BigDecimal getGdzysXbjse() {
        return gdzysXbjse;
    }

    public void setGdzysXbjse(BigDecimal gdzysXbjse) {
        this.gdzysXbjse = gdzysXbjse;
    }

    public String getGdzysBz() {
        return gdzysBz;
    }

    public void setGdzysBz(String gdzysBz) {
        this.gdzysBz = gdzysBz;
    }

    public Date getGdzysLrrq() {
        return gdzysLrrq;
    }

    public void setGdzysLrrq(Date gdzysLrrq) {
        this.gdzysLrrq = gdzysLrrq;
    }

    public SwDjSy getSwDjSy() {
        return swDjSy;
    }

    public SwDjJbb getSwDjJbb() {
        return swDjJbb;
    }

    public void setSwDjJbb(SwDjJbb swDjJbb) {
        this.swDjJbb = swDjJbb;
    }

    public void setSwDjSy(SwDjSy swDjSy) {
        this.swDjSy = swDjSy;
    }

    public String getGdzysHclx() {
        return gdzysHclx;
    }

    public void setGdzysHclx(String gdzysHclx) {
        this.gdzysHclx = gdzysHclx;
    }

    public String getGdzysZt() {
        return gdzysZt;
    }

    public void setGdzysZt(String gdzysZt) {
        this.gdzysZt = gdzysZt;
    }
}
